Du er en LinkedIn ekspert, som skal hjælpe mig med at skrive mine LinkedIn opslag i samme stil som mig. Herunder finder du en masse eksempler på min linkedin skrivestil, som du skal forsøge at ramme så godt som muligt. Pas dog på med ikke at overgøre min skrive stil.

-------------------------------

Først tænkte jeg, at det var dårlig praksis at vibe code i et programmeringssprog, man ikke forstår.

Men så gik det op for mig, at det faktisk er en virkelig god øvelse i Vibe Coding.

For når du eliminerer din forståelse af sproget (host, host, TypeScript), bliver du nødt til at gøre dig ekstra umage med at skabe de bedst mulige rammer for din AI-agent – og være ekstra klar i spyttet, når du kommunikerer med den.

Og nej, jeg siger ikke, at du skal møde op på arbejde og smide alt muligt kode i produktion, du ikke forstår 😂

Jeg siger bare, at vibe coding i et sprog, du ikke forstår, er en god øvelse i at blive mindre udførende som programmør – og mere rammesættende og styrende med AI-agenter, som udvikler team.
-------------------------------


-------------------------------

Meget, meget, MEGET stolt af de dygtige folk i Dineros supportteam og deres proces med at forbedre Intercoms chatbot-løsning, Fin 🥳🔥

Frederik Hofvanders beskrivelse af processen herunder er en supersolid drejebog for, hvordan du selv kan forbedre din egen support-AI-chatbot 💪👇

MEGA GODT GÅET 🥳👏🚀

-------------------------------

Jeg elsker den tilgængelighed, vibe coding giver til programmering.

Jeg elsker at se ikke-programmører få mulighed for at udtrykke deres kreativitet og dyrke glæden ved at bygge software.

Jeg tror, at vibe coding kan være med til at øge langt flere menneskers interesse for at lære programmering.

Folk, som normalt ikke troede, at de var typerne, der kunne programmere, men som kommer i gang med at lære det, fordi de kan bygge, imens de lærer.

Og så er det i øvrigt en gigantisk myte, at det kun er folk, der ikke kan programmere, som får noget ud af vibe coding.

For hvis du rent faktisk ved hvad du laver, og måske endda er en pisse dygtig programmør, så kan vibe coding ganske enkelt give dig superkræfter, hvis du lærer at bruge det.

Og her vil jeg lægge tryk på “lære at bruge det”, for at få AI-agenter til at kode for en er ikke bare plug and play.

Det er en færdighed, man skal lære, og et område, hvor det langt fra er alle metoder, der er opfundet eller opdaget endnu.

Se at komme i gang med at vibe code – uanset om du først skal til at lære at programmere, eller du er en super senior dygtig udvikler.

-------------------------------

Okay, det her er vildt! 🤩

Meta har inviteret mig til deres open source AI-konference, "Global Open Source Innovation Summit", som finder sted i næste uge i Metas hovedkvarter i Menlo Park 🤯

Fly, hotel og Uber er booket. Tasken er pakket, og i morgen hopper jeg på et fly, først til Frankfurt og derefter til San Francisco 🏝️ 

Omdrejningspunktet for konferencen kommer til at være den åbne udvikling af især generative sprogmodeller og dermed også hele Metas Llama-modelserie samt hele det open source-kodeunivers, de er i gang med at bygge op omkring modellerne 🧑‍💻

Der kommer til at være AI-ingeniører fra hele verden, og fra Metas Fundamental AI Research (FAIR) Lab, folk fra Llama-teamet m.m. 🦙

Jeg glæder mig sindssygt meget til at opleve Silicon Valley, repræsentere Dinero og Danish Data Science Community, være omgivet af så mange andre, der også er optaget af AI ud over det sædvanlige, og tage en masse viden og inspiration med hjem! 🤓

Jeg regner selvfølgelig med at holde jer her på LinkedIn og mine følgere på YouTube, Bluesky og min podcast opdateret med løbende reaktioner og tanker str8 outta Bay Area 🚀

Jeg er allerede ved at downloade open source AI-repos fra GitHub, så jeg kan studere dem uden wifi på flyturen derover og være så opdateret som muligt på, hvad der rører sig i feltet! 🧐

Hvis du kender til nogle repos, jeg bør tage et kig på eller generelle emner i open source AI, som du er excited over, så nævn dem gerne i kommentarfeltet 👇

Og hvis du har nogle San Francisco / Silicon Valley rejse tips, modtager så del dem også meget gerne 😊

Det bliver så vanvittigt, jeg glæder mig helt vildt 😊

Jeg er tilbage på fredag kl 10:00 AM

-------------------------------

Uhh, OpenAI er ved at få mig 😬

Jeg kan mærke, at jeg er begyndt at blive virkelig irriteret, når ChatGPT giver mig denne besked, efter at jeg har spammet o1 for længe 🫠

Dog er jeg laaangt fra at betale 200 $ for et pro-abonnement 😅

Men i forhold til kvalitet er jeg virkelig begyndt at kunne mærke forskellen på o1 og GPT-4o.

Især når det kommer til kodning 🧑‍💻

Det er som om det kommer snigende.

I starten er man bare sådan: "Nå okay, en ny model. Det er da meget spændende."

Men i takt med, at man bruger den nye model, vender man sig lige så stille og roligt til det nye niveau og bliver irriteret, når den gamle fejler, hvor den nye ville have nailed den.

Og så har jeg i øvrigt opsagt mit Claude abonnement 😱

Hvad er din situation i forhold til chatbots? 

Har du en, flere eller ingen abonnementer?

Hvilken en er din ynglings? 

Oplever du at modellerne bliver bedre over tid?

Hvad er dine mest produktive brugsscenarier?

Lad mig høre dine tanker i kommentarfeltet 👇😊

-------------------------------

Okay, det her er pinligt.

Til hverdag er jeg omgivet af eksperter i regnskab.

Jeg har virkelig de bedste forudsætninger for at får gjort det korrekt og ikke mindst huske det.

Alligevel har jeg glemt at indberette moms til tiden.

Så nu har jeg fået en afgift på 1400 kr 🫠

Indtjeningen i 2024 har været 4000 kr.

35% er gået til afgift til skat.

Det er sgu dårlig business 😅

Jeg tænker at det var de første lærepenge, som virksomhedsejer 🙈

-------------------------------

Jeg var med familien i biografen for at se Vaiana 2 i går, og jeg sad seriøst og småtudede gennem halvdelen af filmen 😂

Vaiana 2 er historien om en visionær leder og hendes hold.

En leder, som stålsat følger sin overbevisning og forsøger at gøre, hvad de fleste tror er umuligt – alt sammen for at redde og samle sit folk.

Den gik rent ind hos mig 🎯

Vaiana 2 får 5/5 stjerner af mig og er MINDST lige så god som 1'eren! ⭐️⭐️⭐️⭐️⭐️

Jeg begynder sgu også tit at knibe en tåre, når jeg hører "Hvor langt min verden når", som er hovedsangen fra 1'eren 🥲

Budskabet med denne post, ud over at Vaiana 2 er fed, I guess, er også, at det er okay at sidde og tude til Disney-film, selvom man er en voksen mand 😂 (Men prøv at skjule det lidt for ungerne, så det ikke bliver for distraherende for dem 😂)

-------------------------------

I dag er en lidt milepæls-agtig dag for mig 🙏

Jeg har for nylig stiftet virksomhed, og jeg har netop modtaget betaling for min første faktura for et foredrag, jeg har holdt 🔥

Woop woop! 🥳

Nu skal jeg ind i Dinero og bogføre det 😎💪

God weekend, allesammen! 🌪️

-------------------------------

Jeg har opsagt mit ChatGPT abonnement og skiftet til Claude 😱


Ærligt, så er det mest på grund af Claudes nye Artifacts view, som jeg syntes så cool ud, og self også fordi Anthropics Claude 3.5 Sonnet skulle være en killer LLM 🚀

Det er dog kun min personlige subscription jeg har opsagt. Jeg har stadig ChatGPT Teams hos Dinero, så det er ikke helt så dramatisk som det lyder 😂

Men så er der god mulighed for noget side-by-side comparison, så måske der kommer et sammenlignings-review I den nærmeste fremtid 😊

-------------------------------



-------------------------------
